<?php
/*
 * Plugin Name: Wordpress Maintenance
 * Version: 1.1.3
 * Plugin URI: https://webd.uk/support/
 * Description: Maintenance tools for Wordpress
 * Author: Webd Ltd
 * Author URI: https://webd.uk
 * Text Domain: wordpress-maintenance
 */



if (!defined('ABSPATH')) {
    exit('This isn\'t the page you\'re looking for. Move along, move along.');
}



if (!class_exists('wordpress_maintenance_class')) {

	class wordpress_maintenance_class {

        public static $version = '1.1.3';

		function __construct() {

            add_action('plugins_loaded', array($this, 'wordpress_maintenance_enable_database_tools'));

            if (is_admin()) {

                add_action('admin_menu', array($this, 'wordpress_maintenance_menu'));
                add_action('wp_ajax_wordpress_maintenance_toggle_debug_log', array($this,'wordpress_maintenance_toggle_debug_log'));
                add_action('wp_ajax_wordpress_maintenance_delete_empty_wp_cron_events', array($this,'wordpress_maintenance_delete_empty_wp_cron_events'));
                add_action('wp_ajax_wordpress_maintenance_delete_inactive_widgets', array($this,'wordpress_maintenance_delete_inactive_widgets'));
                add_action('wp_ajax_wordpress_maintenance_delete_languages', array($this,'wordpress_maintenance_delete_languages'));
                add_action('wp_ajax_wordpress_maintenance_delete_flamingo', array($this,'wordpress_maintenance_delete_flamingo'));
                add_action('wp_ajax_wordpress_maintenance_delete_comments', array($this,'wordpress_maintenance_delete_comments'));
                add_action('wp_ajax_wordpress_maintenance_close_comments', array($this,'wordpress_maintenance_close_comments'));
                add_action('wp_ajax_wordpress_maintenance_toggle_wp_cron', array($this,'wordpress_maintenance_toggle_wp_cron'));
                add_action('wp_ajax_wordpress_maintenance_toggle_file_edit', array($this,'wordpress_maintenance_toggle_file_edit'));
                add_action('wp_ajax_wordpress_maintenance_enable_updates', array($this,'wordpress_maintenance_enable_updates'));
                add_action('wp_ajax_wordpress_maintenance_disable_links', array($this,'wordpress_maintenance_disable_links'));
                add_action('wp_ajax_wordpress_maintenance_delete_upload_path_option', array($this,'wordpress_maintenance_delete_upload_path_option'));
                add_action('wp_ajax_wordpress_maintenance_convert_tables_to_innodb', array($this,'wordpress_maintenance_convert_tables_to_innodb'));
                add_action('wp_ajax_wordpress_maintenance_change_admin_email', array($this,'wordpress_maintenance_change_admin_email'));
                add_action('wp_ajax_wordpress_maintenance_set_revision_retention', array($this,'wordpress_maintenance_set_revision_retention'));
                add_action('wp_ajax_wordpress_maintenance_recover_custom_css', array($this,'wordpress_maintenance_recover_custom_css'));
                add_action('wp_ajax_wordpress_maintenance_delete_option', array($this,'wordpress_maintenance_delete_option'));

				add_action('wp_ajax_dismiss_wordpress_maintenance_notice_handler', 'wmCommon::ajax_notice_handler');
                add_filter('pre_set_site_transient_update_plugins', 'wmPremium::check_plugin_update');
                add_filter('plugins_api', 'wmPremium::get_plugin_information', 10, 3);
                add_filter('after_plugin_row_' . plugin_basename(__FILE__), 'wmPremium::activate_purchase_js', 10, 3);
                add_action('wp_ajax_wordpress_maintenance_activate_purchase', 'wmPremium::activate_purchase');
                add_action('admin_notices', 'wmPremium::upgrade_notice');
                add_filter('upgrader_pre_download', 'wmPremium::upgrader_pre_download', 10, 3);
                add_filter('plugin_action_links_' . plugin_basename(__FILE__), array($this, 'wordpress_maintenance_add_plugin_settings_links'));

                add_action('wp_dashboard_setup', array($this, 'wp_dashboard_setup'));

                add_filter('pre_option', 'wordpress_maintenance_class::pre_option', 10, 3);
                add_filter('pre_update_option', 'wordpress_maintenance_class::pre_option', 10, 3);
                add_action('shutdown', 'wordpress_maintenance_class::shutdown');

            }

            $revision_retention = absint(get_option('wm_revision_retention'));
            $wordpress_maintenance_daily_schedule = wp_next_scheduled( 'wordpress_maintenance_daily');

            if ($revision_retention) {

                add_action('wordpress_maintenance_daily', 'wordpress_maintenance_class::wm_revision_retention');

                if (!$wordpress_maintenance_daily_schedule) {

                    wp_schedule_event(time(), 'daily', 'wordpress_maintenance_daily');

                }

            } elseif ($wordpress_maintenance_daily_schedule) {

                wp_unschedule_event($wordpress_maintenance_daily_schedule, 'wordpress_maintenance_daily');

            }

		}

		function wordpress_maintenance_add_plugin_settings_links($links) {

			$settings_links = wmCommon::plugin_action_links(add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')), true);

			return array_merge($settings_links, $links);

		}

        public function wordpress_maintenance_enable_database_tools() {

            global $current_user;

            if ($this->request_permission() && current_user_can('manage_options')) {

                define('WP_ALLOW_REPAIR', true);

            }

        }

        public function wordpress_maintenance_menu() {

            add_submenu_page('tools.php', __('Wordpress Maintenance', 'wordpress-maintenance'), __('Maintenance', 'wordpress-maintenance'), 'manage_options', 'wordpress-maintenance', array($this, 'wordpress_maintenance_page'));

        }

        public function wordpress_maintenance_page() {

?>
<div class="wrap">
<h1><?php _e('Wordpress Maintenance', 'wordpress-maintenance'); ?></h1>
<?php

            $current_tab = 'maintenance';

            $tabs = array(
                'maintenance' => 'Maintenance',
                'settings' => 'Settings',
                'phpinfo' => 'PHP Info'
            );

?>
<h2 class="nav-tab-wrapper">
<?php

            foreach ($tabs as $tab => $title) {

                $class = ($current_tab === $tab) ? ' nav-tab-active' : '';

?>
<a id="<?php echo esc_attr($tab); ?>" class="nav-tab<?php echo $class; ?>" href="#" title="<?php echo esc_attr($title); ?>"><?php echo esc_html($title); ?></a>
<?php

            }

?>
</h2>
<script type="text/javascript">
(function($) {
    $('.nav-tab-wrapper .nav-tab').click(function() {
        $('.tab_content').hide();
        $('.tab_content.' + $(this).attr('id')).show();
        $('.nav-tab-active').removeClass('nav-tab-active');
        $(this).addClass('nav-tab-active');
    });
})(jQuery);
</script>
<?php

            global $wpdb;

            if (!wmPremium::request_permission()) {

?>
<div class="notice notice-info">
<p><a href="<?php echo wmCommon::upgrade_link(); ?>" title="<?php _e('Purchase ' . wmCommon::plugin_name(), wmCommon::plugin_text_domain()); ?>">Purchase a license to use these features.</a> Wordpress Maintenance only costs &pound;9.99 and every purchase helps fund further development!</p>
</div>
<?php

            }

?>
<p>Make sure you <strong>take a full filesystem and database backup of your site</strong> before you use any of these tools!</p>
<div class="wrap tab_content maintenance"<?php echo ('maintenance' === $current_tab ? '' : ' style="display: none;"'); ?>>
<h2><?php _e('Maintenance', 'template-editor'); ?></h2>
<?php

            if (-1 === get_theme_mod('custom_css_post_id')) {

                $css_found = false;

                foreach (get_posts(array(
    'post_type' => 'custom_css',
    'numberposts' => -1
)) as $custom_css) {

                    if (get_stylesheet() === $custom_css->post_title) {

                        $css_found = true;

                    }

                }

                if ($css_found) {

?>
<p><span class="wordpress-maintenance-recover-custom-css button button-small<?php if (!$this->request_permission()) { echo ' disabled'; } ?>"><?php _e('Recover Custom CSS', 'wordpress-maintenance'); ?></span> <?php _e('Recover custom CSS that has been located for the active theme', 'wordpress-maintenance'); ?></p>
<?php if ($this->request_permission()) { ?><script type="text/javascript">
(function($) {
    $('.wordpress-maintenance-recover-custom-css').click(function() {
        if (confirm('<?php _e('Are you sure you want to recover custom CSS?', 'wordpress-maintenance'); ?>')) {
            $('.wordpress-maintenance-recover-custom-css').unbind('click')
            var data = {
            	action: 'wordpress_maintenance_recover_custom_css',
            	_ajax_nonce: '<?php echo wp_create_nonce('recover-custom-css'); ?>'
            };
    	    $.ajax({
        	    url: ajaxurl,
        	    data: data,
                type: 'POST',
                success: function(response) {
                    if ('success' in response && response.success) {
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    } else {
                        alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    }
                },
                error: function() {
                    alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                    window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                }
    	    });
        }
    });
})(jQuery);
</script><?php } ?>
<?php

                }

            }

		    $language_issues = array(
                'locales' => array(),
	            'plugins' => array(),
	            'themes' => array()
            );

            if (is_dir(WP_CONTENT_DIR . '/languages/')) {

    		    $iterator = new RecursiveDirectoryIterator(WP_CONTENT_DIR . '/languages/');

        		foreach (new RecursiveIteratorIterator($iterator, RecursiveIteratorIterator::CHILD_FIRST) as $file) {

        			$file_info = pathinfo($file->getPathname());

        			if ($file->isFile() && isset($file_info['extension']) && in_array(strtolower($file_info['extension']), array('mo', 'po', 'json'))) {

                        $language = $file_info['filename'];

                        if (false !== strpos($language, '-')) {

                            if (in_array($file_info['extension'], array('mo', 'po'))) {

                                $directory = rtrim($file_info['dirname'],'/');
                                $directory = substr($directory, strrpos($directory, '/') + 1);

                                if ('languages' !== $directory) {

                                    $theme_or_plugin = substr($language, 0, strrpos($language, '-'));

                                    if (!is_dir(WP_CONTENT_DIR . '/' . $directory . '/' . $theme_or_plugin)) {

                                        if (!isset($language_issues[$directory][$theme_or_plugin])) {

                                            $language_issues[$directory][$theme_or_plugin] = 1;

                                        } else {

                                            $language_issues[$directory][$theme_or_plugin] = $language_issues[$directory][$theme_or_plugin] + 1;

                                        }

                                        if (!isset($language_issues[$directory]['total'])) {

                            				$language_issues[$directory]['total'] = 1;

                                        } else {

                            				$language_issues[$directory]['total'] = $language_issues[$directory]['total'] + 1;

                                        }

                                    }

                                }

                                $language = substr($language, strrpos($language, '-') + 1);

                            } else {

                                $language = preg_replace('/-wc-admin-app$/', '-woocommerce', $language);
                                $language = substr($language, 0, strrpos($language, '-'));
    
                                if (false !== strpos($language, '-')) {

                                    $language = substr($language, strrpos($language, '-') + 1);

                                }

                            }

                        }

                        if ($language !== get_locale()) {

                            if (!isset($language_issues['locales'][$language])) {

                				$language_issues['locales'][$language] = 1;

                            } else {

                				$language_issues['locales'][$language] = $language_issues['locales'][$language] + 1;

                            }

                            if (!isset($language_issues['locales']['total'])) {

                				$language_issues['locales']['total'] = 1;

                            } else {

                				$language_issues['locales']['total'] = $language_issues['locales']['total'] + 1;

                            }

                        }

        			}

        		}

            }

            if ($language_issues['locales']) {

?>
<p><span class="wordpress-maintenance-delete-language-locales button button-small<?php if (!$this->request_permission()) { echo ' disabled'; } ?>"><?php _e('Delete Unused Languages', 'wordpress-maintenance'); ?></span> <?php printf(_n('Delete %d unused language locale file', 'Delete %d unused language locale files', $language_issues['locales']['total'], 'wordpress-maintenance'), $language_issues['locales']['total']) ?> - <?php

    foreach ($language_issues['locales'] as $key => $value) {

        if ('total' !== $key) {

            echo ' Language: ' . esc_html($key) . ' (' . $value . ')';

        }

    }

?></p>
<?php if ($this->request_permission()) { ?><script type="text/javascript">
(function($) {
    $('.wordpress-maintenance-delete-language-locales').click(function() {
        if (confirm('<?php _e('Are you sure you want to delete unused languages?', 'wordpress-maintenance'); ?>')) {
            $('.wordpress-maintenance-delete-language-locales').unbind('click')
            var data = {
            	action: 'wordpress_maintenance_delete_languages',
            	file_type: 'locales',
            	_ajax_nonce: '<?php echo wp_create_nonce('delete-languages-locales'); ?>'
            };
    	    $.ajax({
        	    url: ajaxurl,
        	    data: data,
                type: 'POST',
                success: function(response) {
                    if ('success' in response && response.success) {
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    } else {
                        alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    }
                },
                error: function() {
                    alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                    window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                }
    	    });
        }
    });
})(jQuery);
</script><?php } ?>
<?php

            }

            if ($language_issues['plugins']) {

?>
<p><span class="wordpress-maintenance-delete-language-plugins button button-small<?php if (!$this->request_permission()) { echo ' disabled'; } ?>"><?php _e('Delete Plugin Languages', 'wordpress-maintenance'); ?></span> <?php printf(_n('Delete %d deleted plugin language file', 'Delete %d deleted plugin language files', $language_issues['plugins']['total'], 'wordpress-maintenance'), $language_issues['plugins']['total']) ?> - <?php

    foreach ($language_issues['plugins'] as $key => $value) {

        if ('total' !== $key) {

            echo ' Plugin: ' . esc_html($key) . ' (' . $value . ')';

        }

    }

?></p>
<?php if ($this->request_permission()) { ?><script type="text/javascript">
(function($) {
    $('.wordpress-maintenance-delete-language-plugins').click(function() {
        if (confirm('<?php _e('Are you sure you want to delete plugin languages?', 'wordpress-maintenance'); ?>')) {
            $('.wordpress-maintenance-delete-language-plugins').unbind('click')
            var data = {
            	action: 'wordpress_maintenance_delete_languages',
            	file_type: 'plugins',
            	_ajax_nonce: '<?php echo wp_create_nonce('delete-languages-plugins'); ?>'
            };
    	    $.ajax({
        	    url: ajaxurl,
        	    data: data,
                type: 'POST',
                success: function(response) {
                    if ('success' in response && response.success) {
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    } else {
                        alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    }
                },
                error: function() {
                    alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                    window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                }
    	    });
        }
    });
})(jQuery);
</script><?php } ?>
<?php

            }

            if ($language_issues['themes']) {

?>
<p><span class="wordpress-maintenance-delete-language-themes button button-small<?php if (!$this->request_permission()) { echo ' disabled'; } ?>"><?php _e('Delete Theme Languages', 'wordpress-maintenance'); ?></span> <?php printf(_n('Delete %d deleted theme language file', 'Delete %d deleted theme language files', $language_issues['themes']['total'], 'wordpress-maintenance'), $language_issues['themes']['total']) ?> - <?php

    foreach ($language_issues['themes'] as $key => $value) {

        if ('total' !== $key) {

            echo ' Theme: ' . esc_html($key) . ' (' . $value . ')';

        }

    }

?></p>
<?php if ($this->request_permission()) { ?><script type="text/javascript">
(function($) {
    $('.wordpress-maintenance-delete-language-themes').click(function() {
        if (confirm('<?php _e('Are you sure you want to delete theme languages?', 'wordpress-maintenance'); ?>')) {
            $('.wordpress-maintenance-delete-language-themes').unbind('click')
            var data = {
            	action: 'wordpress_maintenance_delete_languages',
            	file_type: 'themes',
            	_ajax_nonce: '<?php echo wp_create_nonce('delete-languages-themes'); ?>'
            };
    	    $.ajax({
        	    url: ajaxurl,
        	    data: data,
                type: 'POST',
                success: function(response) {
                    if ('success' in response && response.success) {
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    } else {
                        alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    }
                },
                error: function() {
                    alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                    window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                }
    	    });
        }
    });
})(jQuery);
</script><?php } ?>
<?php

            }

            $empty_event_hooks = $this->wordpress_maintenance_get_empty_cron_event_hooks();

            if ($empty_event_hooks) {

?>
<p><span class="wordpress-maintenance-delete-empty-wp-cron-events button button-small<?php if (!$this->request_permission()) { echo ' disabled'; } ?>"><?php _e('Delete Empty WP CRON Events', 'wordpress-maintenance'); ?></span> <?php printf(_n('Delete %d scheduled event hook (%s) in WP CRON that have no associated actions.', 'Delete %d scheduled event hooks (%s) in WP CRON that have no associated actions.', count($empty_event_hooks), 'wordpress-maintenance'), count($empty_event_hooks), implode(', ', $empty_event_hooks)); ?></p>
<?php if ($this->request_permission()) { ?><script type="text/javascript">
(function($) {
    $('.wordpress-maintenance-delete-empty-wp-cron-events').click(function() {
        if (confirm('<?php _e('Are you sure you want to delete empty WP CRON events?', 'wordpress-maintenance'); ?>')) {
            $('.wordpress-maintenance-delete-empty-wp-cron-events').unbind('click')
            var data = {
            	action: 'wordpress_maintenance_delete_empty_wp_cron_events',
            	_ajax_nonce: '<?php echo wp_create_nonce('delete-empty-wp-cron-events'); ?>'
            };
    	    $.ajax({
        	    url: ajaxurl,
        	    data: data,
                type: 'POST',
                success: function(response) {
                    if ('success' in response && response.success) {
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    } else {
                        alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    }
                },
                error: function() {
                    alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                    window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                }
    	    });
        }
    });
})(jQuery);
</script><?php } ?>
<?php

            }

            $sidebars_widgets = wp_get_sidebars_widgets();
            $inactive_widget_count = 0;
            $legacy_widget_count = 0;

            if (is_array($sidebars_widgets) && $sidebars_widgets) {

                foreach ($sidebars_widgets as $sidebar_id => $widgets) {

                    foreach ($widgets as $widget) {

                        if (0 !== substr_compare($widget, 'block-', 0, 6)) {

                            $legacy_widget_count++;

                        }

                    }

                	if (!('wp_inactive_widgets' !== $sidebar_id && is_registered_sidebar($sidebar_id)) && $widgets) {

                    	$inactive_widget_count += count($widgets);

                	}

                }

            }

            if ($inactive_widget_count) {

?>
<p><span class="wordpress-maintenance-delete-inactive-widgets button button-small<?php if (!$this->request_permission()) { echo ' disabled'; } ?>"><?php _e('Delete Inactive Widgets', 'wordpress-maintenance'); ?></span> <?php printf(_n('Delete %d inactive widget that does not have an associated sidebar.', 'Delete %d inactive widgets that do not have an associated sidebar.', $inactive_widget_count, 'wordpress-maintenance'), $inactive_widget_count); ?></p>
<?php if ($this->request_permission()) { ?><script type="text/javascript">
(function($) {
    $('.wordpress-maintenance-delete-inactive-widgets').click(function() {
        if (confirm('<?php _e('Are you sure you want to delete inactive widgets?', 'wordpress-maintenance'); ?>')) {
            $('.wordpress-maintenance-delete-inactive-widgets').unbind('click')
            var data = {
            	action: 'wordpress_maintenance_delete_inactive_widgets',
            	_ajax_nonce: '<?php echo wp_create_nonce('delete-inactive-widgets'); ?>'
            };
    	    $.ajax({
        	    url: ajaxurl,
        	    data: data,
                type: 'POST',
                success: function(response) {
                    if ('success' in response && response.success) {
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    } else {
                        alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    }
                },
                error: function() {
                    alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                    window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                }
    	    });
        }
    });
})(jQuery);
</script><?php } ?>
<?php

            }

            if ($legacy_widget_count) {

?>
<p><a class="button button-small" title="<?php _e('Edit Widgets', 'wordpress-maintenance'); ?>" href="<?php echo esc_url(admin_url('widgets.php')); ?>"><?php _e('Edit Widgets', 'wordpress-maintenance'); ?></a> <?php printf(_n('You have a legacy widget. ', 'You have %d legacy widgets. ', $legacy_widget_count, 'wordpress-maintenance'), $legacy_widget_count); ?><?php _e('Legacy widgets cause issues in the Block Widget editor due to a <a href="https://core.trac.wordpress.org/ticket/53801">bug whereby the wp_footer hook is fired</a>. You should convert them to Block Widgets.', 'wordpress-maintenance'); ?></p>
<?php

            }

            $flamingo_contacts = get_posts(array(
                'post_type' => 'flamingo_contact',
                'numberposts' => -1,
                'fields' => 'ids'
            ));

            if ($flamingo_contacts) {

?>
<p><span class="wordpress-maintenance-delete-flamingo-contacts button button-small<?php if (!$this->request_permission()) { echo ' disabled'; } ?>"><?php _e('Delete Flamingo Contacts', 'wordpress-maintenance'); ?></span> <?php printf(_n('Delete %d Flamingo contact.', 'Delete %d Flamingo contacts.', count($flamingo_contacts), 'wordpress-maintenance'), count($flamingo_contacts)) ?></p>
<?php if ($this->request_permission()) { ?><script type="text/javascript">
(function($) {
    $('.wordpress-maintenance-delete-flamingo-contacts').click(function() {
        if (confirm('<?php _e('Are you sure you want to delete Flamingo contacts?', 'wordpress-maintenance'); ?>')) {
            $('.wordpress-maintenance-delete-flamingo-contacts').unbind('click')
            var data = {
            	action: 'wordpress_maintenance_delete_flamingo',
            	post_type: 'flamingo_contact',
            	_ajax_nonce: '<?php echo wp_create_nonce('delete-flamingo-flamingo_contact'); ?>'
            };
    	    $.ajax({
        	    url: ajaxurl,
        	    data: data,
                type: 'POST',
                success: function(response) {
                    if ('success' in response && response.success) {
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    } else {
                        alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    }
                },
                error: function() {
                    alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                    window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                }
    	    });
        }
    });
})(jQuery);
</script><?php } ?>
<?php

            }

            $flamingo_messages = get_posts(array(
                'post_type' => 'flamingo_inbound',
                'numberposts' => -1,
                'fields' => 'ids'
            ));

            if ($flamingo_messages) {

?>
<p><span class="wordpress-maintenance-delete-flamingo-messages button button-small<?php if (!$this->request_permission()) { echo ' disabled'; } ?>"><?php _e('Delete Flamingo Messages', 'wordpress-maintenance'); ?></span> <?php printf(_n('Delete %d Flamingo message.', 'Delete %d Flamingo messages.', count($flamingo_messages), 'wordpress-maintenance'), count($flamingo_messages)) ?></p>
<?php if ($this->request_permission()) { ?><script type="text/javascript">
(function($) {
    $('.wordpress-maintenance-delete-flamingo-messages').click(function() {
        if (confirm('<?php _e('Are you sure you want to delete Flamingo messages?', 'wordpress-maintenance'); ?>')) {
            $('.wordpress-maintenance-delete-flamingo-messages').unbind('click')
            var data = {
            	action: 'wordpress_maintenance_delete_flamingo',
            	post_type: 'flamingo_inbound',
            	_ajax_nonce: '<?php echo wp_create_nonce('delete-flamingo-flamingo_inbound'); ?>'
            };
    	    $.ajax({
        	    url: ajaxurl,
        	    data: data,
                type: 'POST',
                success: function(response) {
                    if ('success' in response && response.success) {
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    } else {
                        alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    }
                },
                error: function() {
                    alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                    window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                }
    	    });
        }
    });
})(jQuery);
</script><?php } ?>
<?php

            }

            $flamingo_messages = get_posts(array(
                'post_type' => 'flamingo_inbound',
                'post_status' => 'flamingo-spam',
                'numberposts' => -1,
                'fields' => 'ids'
            ));

            if ($flamingo_messages) {

?>
<p><span class="wordpress-maintenance-delete-flamingo-spam button button-small<?php if (!$this->request_permission()) { echo ' disabled'; } ?>"><?php _e('Delete Flamingo Spam', 'wordpress-maintenance'); ?></span> <?php printf(_n('Delete %d Flamingo spam message.', 'Delete %d Flamingo spam messages.', count($flamingo_messages), 'wordpress-maintenance'), count($flamingo_messages)) ?></p>
<?php if ($this->request_permission()) { ?><script type="text/javascript">
(function($) {
    $('.wordpress-maintenance-delete-flamingo-spam').click(function() {
        if (confirm('<?php _e('Are you sure you want to delete Flamingo spam messages?', 'wordpress-maintenance'); ?>')) {
            $('.wordpress-maintenance-delete-flamingo-spam').unbind('click')
            var data = {
            	action: 'wordpress_maintenance_delete_flamingo',
            	post_type: 'flamingo_inbound',
            	post_status: 'flamingo-spam',
            	_ajax_nonce: '<?php echo wp_create_nonce('delete-flamingo-flamingo_inbound'); ?>'
            };
    	    $.ajax({
        	    url: ajaxurl,
        	    data: data,
                type: 'POST',
                success: function(response) {
                    if ('success' in response && response.success) {
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    } else {
                        alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    }
                },
                error: function() {
                    alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                    window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                }
    	    });
        }
    });
})(jQuery);
</script><?php } ?>
<?php

            }

            $flamingo_messages = get_posts(array(
                'post_type' => 'flamingo_inbound',
                'post_status' => 'trash',
                'numberposts' => -1,
                'fields' => 'ids'
            ));

            if ($flamingo_messages) {

?>
<p><span class="wordpress-maintenance-delete-flamingo-trash button button-small<?php if (!$this->request_permission()) { echo ' disabled'; } ?>"><?php _e('Delete Flamingo Trash', 'wordpress-maintenance'); ?></span> <?php printf(_n('Delete %d Flamingo trash message.', 'Delete %d Flamingo trash messages.', count($flamingo_messages), 'wordpress-maintenance'), count($flamingo_messages)) ?></p>
<?php if ($this->request_permission()) { ?><script type="text/javascript">
(function($) {
    $('.wordpress-maintenance-delete-flamingo-trash').click(function() {
        if (confirm('<?php _e('Are you sure you want to delete Flamingo trash messages?', 'wordpress-maintenance'); ?>')) {
            $('.wordpress-maintenance-delete-flamingo-trash').unbind('click')
            var data = {
            	action: 'wordpress_maintenance_delete_flamingo',
            	post_type: 'flamingo_inbound',
            	post_status: 'trash',
            	_ajax_nonce: '<?php echo wp_create_nonce('delete-flamingo-flamingo_inbound'); ?>'
            };
    	    $.ajax({
        	    url: ajaxurl,
        	    data: data,
                type: 'POST',
                success: function(response) {
                    if ('success' in response && response.success) {
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    } else {
                        alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    }
                },
                error: function() {
                    alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                    window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                }
    	    });
        }
    });
})(jQuery);
</script><?php } ?>
<?php

            }

            $revisions = get_posts(array(
                'post_type' => 'revision',
                'post_status' => 'inherit',
                'numberposts' => -1,
                'fields' => 'ids'
            ));

            if ($revisions && !absint(get_option('wm_revision_retention'))) {

?>
<p><span class="wordpress-maintenance-delete-revisions button button-small<?php if (!$this->request_permission()) { echo ' disabled'; } ?>"><?php _e('Delete Revisions', 'wordpress-maintenance'); ?></span> <?php printf(_n('Delete %d post revision.', 'Delete %d post revisions.', count($revisions), 'wordpress-maintenance'), count($revisions)) ?></p>
<?php if ($this->request_permission()) { ?><script type="text/javascript">
(function($) {
    $('.wordpress-maintenance-delete-revisions').click(function() {
        if (confirm('<?php _e('Are you sure you want to delete post revisions?', 'wordpress-maintenance'); ?>')) {
            $('.wordpress-maintenance-delete-revisions').unbind('click')
            var data = {
            	action: 'wordpress_maintenance_delete_flamingo',
            	post_type: 'revision',
            	_ajax_nonce: '<?php echo wp_create_nonce('delete-flamingo-revision'); ?>'
            };
    	    $.ajax({
        	    url: ajaxurl,
        	    data: data,
                type: 'POST',
                success: function(response) {
                    if ('success' in response && response.success) {
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    } else {
                        alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    }
                },
                error: function() {
                    alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                    window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                }
    	    });
        }
    });
})(jQuery);
</script><?php } ?>
<?php

            }

            $auto_drafts = get_posts(array(
                'post_type' => 'any',
                'post_status' => 'auto-draft',
                'numberposts' => -1,
                'fields' => 'ids'
            ));

            if ($auto_drafts) {

?>
<p><span class="wordpress-maintenance-delete-auto-drafts button button-small<?php if (!$this->request_permission()) { echo ' disabled'; } ?>"><?php _e('Delete Auto Drafts', 'wordpress-maintenance'); ?></span> <?php printf(_n('Delete %d auto draft.', 'Delete %d auto drafts.', count($auto_drafts), 'wordpress-maintenance'), count($auto_drafts)) ?></p>
<?php if ($this->request_permission()) { ?><script type="text/javascript">
(function($) {
    $('.wordpress-maintenance-delete-auto-drafts').click(function() {
        if (confirm('<?php _e('Are you sure you want to delete auto drafts?', 'wordpress-maintenance'); ?>')) {
            $('.wordpress-maintenance-delete-auto-drafts').unbind('click')
            var data = {
            	action: 'wordpress_maintenance_delete_flamingo',
            	post_type: 'any',
            	_ajax_nonce: '<?php echo wp_create_nonce('delete-flamingo-any'); ?>'
            };
    	    $.ajax({
        	    url: ajaxurl,
        	    data: data,
                type: 'POST',
                success: function(response) {
                    if ('success' in response && response.success) {
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    } else {
                        alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    }
                },
                error: function() {
                    alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                    window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                }
    	    });
        }
    });
})(jQuery);
</script><?php } ?>
<?php

            }

            $comments = get_comments(array(
                'status' => 'hold',
                'count' => true
            ));

            if ($comments) {

?>
<p><span class="wordpress-maintenance-delete-hold-comments button button-small<?php if (!$this->request_permission()) { echo ' disabled'; } ?>"><?php _e('Delete Pending Comments', 'wordpress-maintenance'); ?></span> <?php printf(_n('Delete %d pending comment.', 'Delete %d pending comments.', $comments, 'wordpress-maintenance'), $comments); ?></p>
<?php if ($this->request_permission()) { ?><script type="text/javascript">
(function($) {
    $('.wordpress-maintenance-delete-hold-comments').click(function() {
        if (confirm('<?php _e('Are you sure you want to delete pending comments?', 'wordpress-maintenance'); ?>')) {
            $('.wordpress-maintenance-delete-hold-comments').unbind('click')
            var data = {
            	action: 'wordpress_maintenance_delete_comments',
            	status: 'hold',
            	_ajax_nonce: '<?php echo wp_create_nonce('delete-hold-comments'); ?>'
            };
    	    $.ajax({
        	    url: ajaxurl,
        	    data: data,
                type: 'POST',
                success: function(response) {
                    if ('success' in response && response.success) {
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    } else {
                        alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    }
                },
                error: function() {
                    alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                    window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                }
    	    });
        }
    });
})(jQuery);
</script><?php } ?>
<?php

            }

            $comments = get_comments(array(
                'status' => 'spam',
                'count' => true
            ));

            if ($comments) {

?>
<p><span class="wordpress-maintenance-delete-spam-comments button button-small<?php if (!$this->request_permission()) { echo ' disabled'; } ?>"><?php _e('Delete Spam Comments', 'wordpress-maintenance'); ?></span> <?php printf(_n('Delete %d spam comment.', 'Delete %d spam comments.', $comments, 'wordpress-maintenance'), $comments); ?></p>
<?php if ($this->request_permission()) { ?><script type="text/javascript">
(function($) {
    $('.wordpress-maintenance-delete-spam-comments').click(function() {
        if (confirm('<?php _e('Are you sure you want to delete spam comments?', 'wordpress-maintenance'); ?>')) {
            $('.wordpress-maintenance-delete-spam-comments').unbind('click')
            var data = {
            	action: 'wordpress_maintenance_delete_comments',
            	status: 'spam',
            	_ajax_nonce: '<?php echo wp_create_nonce('delete-spam-comments'); ?>'
            };
    	    $.ajax({
        	    url: ajaxurl,
        	    data: data,
                type: 'POST',
                success: function(response) {
                    if ('success' in response && response.success) {
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    } else {
                        alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    }
                },
                error: function() {
                    alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                    window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                }
    	    });
        }
    });
})(jQuery);
</script><?php } ?>
<?php

            }

            $comments = get_comments(array(
                'status' => 'trash',
                'count' => true
            ));

            if ($comments) {

?>
<p><span class="wordpress-maintenance-delete-trash-comments button button-small<?php if (!$this->request_permission()) { echo ' disabled'; } ?>"><?php _e('Empty Comments Bin', 'wordpress-maintenance'); ?></span> <?php printf(_n('Delete %d comment from the bin.', 'Delete %d comments from the bin.', $comments, 'wordpress-maintenance'), $comments); ?></p>
<?php if ($this->request_permission()) { ?><script type="text/javascript">
(function($) {
    $('.wordpress-maintenance-delete-trash-comments').click(function() {
        if (confirm('<?php _e('Are you sure you want to empty the comments bin?', 'wordpress-maintenance'); ?>')) {
            $('.wordpress-maintenance-delete-trash-comments').unbind('click')
            var data = {
            	action: 'wordpress_maintenance_delete_comments',
            	status: 'trash',
            	_ajax_nonce: '<?php echo wp_create_nonce('delete-trash-comments'); ?>'
            };
    	    $.ajax({
        	    url: ajaxurl,
        	    data: data,
                type: 'POST',
                success: function(response) {
                    if ('success' in response && response.success) {
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    } else {
                        alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    }
                },
                error: function() {
                    alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                    window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                }
    	    });
        }
    });
})(jQuery);
</script><?php } ?>
<?php

            }

            if ('closed' === get_option('default_comment_status')) {

                $comments = get_comments(array(
                    'status' => 'all',
                    'count' => true,
                    'type__not_in' => 'order_note'
                ));

                if ($comments) {

?>
<p><span class="wordpress-maintenance-delete-all-comments button button-small<?php if (!$this->request_permission()) { echo ' disabled'; } ?>" style="color: red;"><?php _e('Delete All Comments', 'wordpress-maintenance'); ?></span> <?php printf(_n('Delete %d comment.', 'Delete %d comments.', $comments, 'wordpress-maintenance'), $comments); ?></p>
<?php if ($this->request_permission()) { ?><script type="text/javascript">
(function($) {
    $('.wordpress-maintenance-delete-all-comments').click(function() {
        if (confirm('<?php _e('Are you sure you want to delete all comments?', 'wordpress-maintenance'); ?>')) {
            $('.wordpress-maintenance-delete-all-comments').unbind('click')
            var data = {
            	action: 'wordpress_maintenance_delete_comments',
            	status: 'all',
            	_ajax_nonce: '<?php echo wp_create_nonce('delete-all-comments'); ?>'
            };
    	    $.ajax({
        	    url: ajaxurl,
        	    data: data,
                type: 'POST',
                success: function(response) {
                    if ('success' in response && response.success) {
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    } else {
                        alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    }
                },
                error: function() {
                    alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                    window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                }
    	    });
        }
    });
})(jQuery);
</script><?php } ?>
<?php

                }

            }

            $posts = get_posts(array(
                'comment_status' => 'open',
                'posts_per_page' => -1,
                'post_type' => 'any'
            ));

            if ($posts || 'open' === get_option('default_comment_status')) {

?>
<p><span class="wordpress-maintenance-close-comments button button-small<?php if (!$this->request_permission()) { echo ' disabled'; } ?>"><?php _e('Close Comments', 'wordpress-maintenance'); ?></span> <?php printf(_n('Close comments on %d post and future posts.', 'Close commments on %d posts and future posts.', count($posts), 'wordpress-maintenance'), count($posts)); ?></p>
<?php if ($this->request_permission()) { ?><script type="text/javascript">
(function($) {
    $('.wordpress-maintenance-close-comments').click(function() {
        if (confirm('<?php _e('Are you sure you want to close comments on all posts?', 'wordpress-maintenance'); ?>')) {
            $('.wordpress-maintenance-close-comments').unbind('click')
            var data = {
            	action: 'wordpress_maintenance_close_comments',
            	_ajax_nonce: '<?php echo wp_create_nonce('close-comments'); ?>'
            };
    	    $.ajax({
        	    url: ajaxurl,
        	    data: data,
                type: 'POST',
                success: function(response) {
                    if ('success' in response && response.success) {
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    } else {
                        alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    }
                },
                error: function() {
                    alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                    window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                }
    	    });
        }
    });
})(jQuery);
</script><?php } ?>
<?php

            }

            if (get_option('link_manager_enabled', true)) {

?>
<p><span class="wordpress-maintenance-disable-links button button-small<?php if (!$this->request_permission()) { echo ' disabled'; } ?>"><?php _e('Disable Links', 'wordpress-maintenance'); ?></span> <?php _e('Delete existing links and disable link manager.', 'wordpress-maintenance'); ?></p>
<?php if ($this->request_permission()) { ?><script type="text/javascript">
(function($) {
    $('.wordpress-maintenance-disable-links').click(function() {
        if (confirm('<?php _e('Are you sure you want to delete links and dissable link manager?', 'wordpress-maintenance'); ?>')) {
            $('.wordpress-maintenance-disable-links').unbind('click')
            var data = {
            	action: 'wordpress_maintenance_disable_links',
            	_ajax_nonce: '<?php echo wp_create_nonce('disable-links'); ?>'
            };
    	    $.ajax({
        	    url: ajaxurl,
        	    data: data,
                type: 'POST',
                success: function(response) {
                    if ('success' in response && response.success) {
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    } else {
                        alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    }
                },
                error: function() {
                    alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                    window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                }
    	    });
        }
    });
})(jQuery);
</script><?php } ?>
<?php

            }

            if (get_option('upload_path')) {

?>
<p><span class="wordpress-maintenance-delete-upload-path-option button button-small<?php if (!$this->request_permission()) { echo ' disabled'; } ?>"><?php _e('Delete Upload Path Option', 'wordpress-maintenance'); ?></span> <?php _e('Delete the upload_path option from the wp_options table in the database.', 'wordpress-maintenance'); ?></p>
<?php if ($this->request_permission()) { ?><script type="text/javascript">
(function($) {
    $('.wordpress-maintenance-delete-upload-path-option').click(function() {
        if (confirm('<?php _e('Are you sure you want to delete the upload_path option?', 'wordpress-maintenance'); ?>')) {
            $('.wordpress-maintenance-delete-upload-path-option').unbind('click')
            var data = {
            	action: 'wordpress_maintenance_delete_upload_path_option',
            	_ajax_nonce: '<?php echo wp_create_nonce('delete-upload-path-option'); ?>'
            };
    	    $.ajax({
        	    url: ajaxurl,
        	    data: data,
                type: 'POST',
                success: function(response) {
                    if ('success' in response && response.success) {
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    } else {
                        alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    }
                },
                error: function() {
                    alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                    window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                }
    	    });
        }
    });
})(jQuery);
</script><?php } ?>
<?php

            }

            $database_tables = $wpdb->get_results("SHOW TABLE STATUS");
            $myisam_tables = array();

            foreach ($database_tables as $key => $database_table) {

                if (
                    'InnoDB' !== $database_table->Engine && 
                    'MEMORY' !== $database_table->Engine
                ) {

                    $myisam_tables[] = $database_table->Name;

                }

            }

            if ($myisam_tables) {

?>
<p><span class="wordpress-maintenance-convert-tables-to-innodb button button-small<?php if (!$this->request_permission()) { echo ' disabled'; } ?>"><?php _e('Convert Tables to InnoDB', 'wordpress-maintenance'); ?></span> <?php printf(__('Convert the MyISAM tables (%s) in the database to InnoDB.', 'wordpress-maintenance'), implode(',', $myisam_tables)); ?></p>
<?php if ($this->request_permission()) { ?><script type="text/javascript">
(function($) {
    $('.wordpress-maintenance-convert-tables-to-innodb').click(function() {
        if (confirm('<?php _e('Are you sure you want to convert the database tables to InnoDB?', 'wordpress-maintenance'); ?>')) {
            $('.wordpress-maintenance-convert-tables-to-innodb').unbind('click')
            var data = {
            	action: 'wordpress_maintenance_convert_tables_to_innodb',
            	_ajax_nonce: '<?php echo wp_create_nonce('convert-tables-to-innodb'); ?>'
            };
    	    $.ajax({
        	    url: ajaxurl,
        	    data: data,
                type: 'POST',
                success: function(response) {
                    if ('success' in response && response.success) {
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    } else {
                        alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    }
                },
                error: function() {
                    alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                    window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                }
    	    });
        }
    });
})(jQuery);
</script><?php } ?>
<?php

            }

?>
<p><a class="button button-small<?php if (!$this->request_permission()) { echo ' disabled'; } ?>"<?php if ($this->request_permission()) { echo ' target="_blank"'; } ?> href="<?php echo $this->request_permission() ? admin_url('maint/repair.php') : '#'; ?>"><?php echo esc_html__('Open Database Tools', 'wordpress-maintenance'); ?></a> <?php _e('Open WordPress database repair and optimize tools.', 'wordpress-maintenance'); ?></p>
<p>Admin Email: <input type="email" id="wordpress-maintenance-admin-email" value="<?php echo esc_attr(get_option('admin_email')); ?>" /><br />
<span class="wordpress-maintenance-change-admin-email button button-small<?php if (!$this->request_permission()) { echo ' disabled'; } ?>"><?php _e('Change Admin Email', 'wordpress-maintenance'); ?></span> <?php _e('Change admin email in general settings without requiring a confirmation email.', 'wordpress-maintenance'); ?></p>
<?php if ($this->request_permission()) { ?><script type="text/javascript">
(function($) {
    $('.wordpress-maintenance-change-admin-email').click(function() {
        if (confirm('<?php _e('Are you sure you want to change the admin email?', 'wordpress-maintenance'); ?>')) {
            $('.wordpress-maintenance-change-admin-email').unbind('click')
            var data = {
            	action: 'wordpress_maintenance_change_admin_email',
            	_ajax_nonce: '<?php echo wp_create_nonce('change-admin-email'); ?>',
            	email: $('#wordpress-maintenance-admin-email').val()
            };
    	    $.ajax({
        	    url: ajaxurl,
        	    data: data,
                type: 'POST',
                success: function(response) {
                    if ('success' in response && response.success) {
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    } else {
                        alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    }
                },
                error: function() {
                    alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                    window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                }
    	    });
        }
    });
})(jQuery);
</script><?php } ?>
<?php

            $persistent_object_cache_issues = array();

    		$thresholds = apply_filters(
    			'site_status_persistent_object_cache_thresholds',
    			array(
    				'alloptions_count' => 500,
    				'alloptions_bytes' => 100000,
    				'comments_count'   => 1000,
    				'options_count'    => 1000,
    				'posts_count'      => 1000,
    				'terms_count'      => 1000,
    				'users_count'      => 1000,
    			)
    		);

    		$alloptions = wp_load_alloptions();
            $show_options_that_can_be_deleted = false;

    		if ($thresholds['alloptions_count'] < count($alloptions)) {

                $show_options_that_can_be_deleted = true;
			    $persistent_object_cache_issues[] = sprintf(__('You have more than %s options (%s)'), number_format($thresholds['alloptions_count']), number_format(count($alloptions)));

    		}

    		if ( $thresholds['alloptions_bytes'] < strlen( serialize( $alloptions ) ) ) {

                $show_options_that_can_be_deleted = true;
			    $persistent_object_cache_issues[] = sprintf(__('You have more than %s bytes of options (%s bytes)'), number_format($thresholds['alloptions_bytes']), number_format(strlen(serialize($alloptions))));

    		}

    		$table_names = implode("','", array($wpdb->comments, $wpdb->options, $wpdb->posts, $wpdb->terms, $wpdb->users));

    		$results = $wpdb->get_results(
    			$wpdb->prepare(
    				"SELECT TABLE_NAME AS 'table', TABLE_ROWS AS 'rows', SUM(data_length + index_length) as 'bytes' FROM information_schema.TABLES WHERE TABLE_SCHEMA = %s AND TABLE_NAME IN ('$table_names') GROUP BY TABLE_NAME;",
    				DB_NAME
        			),
    			OBJECT_K
    		);

    		$threshold_map = array(
    			'comments_count' => $wpdb->comments,
    			'options_count'  => $wpdb->options,
    			'posts_count'    => $wpdb->posts,
    			'terms_count'    => $wpdb->terms,
    			'users_count'    => $wpdb->users,
    		);

    		foreach ($threshold_map as $threshold => $table) {

    			if ($thresholds[$threshold] <= $results[$table]->rows) {

    			    $persistent_object_cache_issues[] = sprintf(__('You have more than %s rows in %s (%s)'), number_format($thresholds[$threshold]), $table, number_format($results[$table]->rows));

    			}

    		}

            if ($persistent_object_cache_issues) {

?>
<h2><?php _e('Persistent Object Cache'); ?></h2>
<p><?php _e('Since WordPress v6.1 the Site Health check has started recommending if you should be using a "Persistent Object Cache" without actually explaining why. Here\'s why ...'); ?></p>
<ol>
<?php

                foreach ($persistent_object_cache_issues as $persistent_object_cache_issue) {

                    echo '<li>' . $persistent_object_cache_issue . '</li>';

                }
?>
</ol>
<?php

                $active_options = get_option('active_options');

                if ($show_options_that_can_be_deleted && $active_options && is_array($active_options)) {

                    unset($alloptions['active_options']);
                    unset($alloptions['rewrite_rules']);

                    foreach ($active_options as $option_name) {

                        unset($alloptions[$option_name]);

                    }

                    $inactive_options = array();
                    ksort($alloptions);

                    foreach ($alloptions as $option_name => $option_value) {

                        $inactive_options[] = '<div class="wm_option_' . esc_attr($option_name) . '" title="' . esc_attr(print_r(maybe_unserialize($option_value), true)) . '">' . esc_html($option_name) . ' <span class="dashicons dashicons-trash wm-delete-option" data-option="' . esc_attr($option_name) . '"></span> <a href="https://www.google.com/search?q=' . urlencode($option_name) . '" target="_blank" style="text-decoration: none;"><span class="dashicons dashicons-search"></span></a></div>';
                        $alloptions[$option_name] = strlen($option_value);

                    }

                    arsort($alloptions);
                    $largest_inactive_options = array_slice($alloptions, 0, 10);
                    $largest_options = array();

                    foreach ($largest_inactive_options as $option_name => $option_size) {

                        $largest_options[] = '<div class="wm_option_' . esc_attr($option_name) . '">' . esc_html($option_name) . ' (' . number_format($option_size/(1<<10), 2) . 'Kb' . ') <span class="dashicons dashicons-trash wm-delete-option" data-option="' . esc_attr($option_name) . '"></span> <a href="https://www.google.com/search?q=' . urlencode($option_name) . '" target="_blank" style="text-decoration: none;"><span class="dashicons dashicons-search"></span></a></div>';

                    }

?>
<h3><?php _e('Options that have not been used recently:'); ?></h3>
<p><?php echo implode(PHP_EOL, $inactive_options); ?></p>
<?php

?>
<h3><?php _e('Largest options:'); ?></h3>
<p><?php echo implode(PHP_EOL, $largest_options); ?></p>
<?php if ($this->request_permission()) { ?><script type="text/javascript">
(function($) {
    $('.wm-delete-option').click(function() {
        if (confirm('<?php _e('Are you sure you want to delete the option', 'wordpress-maintenance'); ?> "' + this.getAttribute('data-option') + '"')) {
            $(this).unbind('click')
            var targetOption = this,
            data = {
            	action: 'wordpress_maintenance_delete_option',
            	option: this.getAttribute('data-option'),
            	_ajax_nonce: '<?php echo wp_create_nonce('delete-option'); ?>'
            };
    	    $.ajax({
        	    url: ajaxurl,
        	    data: data,
                type: 'POST',
                success: function(response) {
                    if ('success' in response && response.success) {
                        targetOption.parentElement.remove();
                    } else {
                        alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    }
                },
                error: function() {
                    alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                    window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                }
    	    });
        }
    });
})(jQuery);
</script><?php } ?>
<?php

                }


            }

?>

</div>
<div class="wrap tab_content settings"<?php echo ('settings' === $current_tab ? '' : ' style="display: none;"'); ?>>
<h2><?php _e('Settings', 'template-editor'); ?></h2>
<?php

            $can_edit_wp_config = true;

			if (!file_exists(wmCommon::get_home_path() . 'wp-config.php')) {

                $can_edit_wp_config = false;

?>
<p style="color: red;"><strong>Cannot find "wp-config.php"!</strong></p>
<?php

            } elseif (!is_writable(wmCommon::get_home_path() . 'wp-config.php')) {

                $can_edit_wp_config = false;

?>
<p style="color: red;"><strong>Cannot write to "wp-config.php"!</strong></p>
<?php

            }

            if ($can_edit_wp_config) {

				$wp_config = explode("\n", implode('', file(wmCommon::get_home_path() . 'wp-config.php')));
				$toggle_debug_log = __('Enable', 'wordpress-maintenance');
				$toggle_wp_cron = __('Disable', 'wordpress-maintenance');
				$toggle_file_edit = __('Disable', 'wordpress-maintenance');

				foreach ($wp_config as $line) {

					if (preg_match('/^define\(\s?["\']{1}WP_DEBUG["\']{1},\s?true/i', $line)) {

					    $toggle_debug_log = __('Disable', 'wordpress-maintenance');

					}

					if (preg_match('/^define\(\s?["\']{1}DISABLE_WP_CRON["\']{1},\s?true/i', $line)) {

					    $toggle_wp_cron = __('Enable', 'wordpress-maintenance');

					}

					if (preg_match('/^define\(\s?["\']{1}DISALLOW_FILE_EDIT["\']{1},\s?true/i', $line)) {

					    $toggle_file_edit = __('Enable', 'wordpress-maintenance');

					}
				}

?>
<p><span class="wordpress-maintenance-toggle-debug-log button button-small<?php if (!$this->request_permission()) { echo ' disabled'; } ?>"><?php echo $toggle_debug_log; ?> debug.log</span> <?php echo $toggle_debug_log; ?> debug.log <?php _e('in wp-config.php.', 'wordpress-maintenance'); ?></p>
<?php if ($this->request_permission()) { ?><script type="text/javascript">
(function($) {
    $('.wordpress-maintenance-toggle-debug-log').click(function() {
        if (confirm('<?php printf(__('Are you sure you want to %s debug.log?', 'wordpress-maintenance'), strtolower($toggle_debug_log)); ?>')) {
            $('.wordpress-maintenance-toggle-debug-log').unbind('click')
            var data = {
            	action: 'wordpress_maintenance_toggle_debug_log',
            	_ajax_nonce: '<?php echo wp_create_nonce('toggle-debug-log'); ?>'
            };
    	    $.ajax({
        	    url: ajaxurl,
        	    data: data,
                type: 'POST',
                success: function(response) {
                    if ('success' in response && response.success) {
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    } else {
                        alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    }
                },
                error: function() {
                    alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                    window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                }
    	    });
        }
    });
})(jQuery);
</script><?php } ?>

<p><span class="wordpress-maintenance-toggle-wp-cron button button-small<?php if (!$this->request_permission()) { echo ' disabled'; } ?>"><?php echo $toggle_wp_cron; ?> WP CRON</span> <?php echo $toggle_wp_cron; ?> WP CRON <?php _e('in wp-config.php.', 'wordpress-maintenance'); ?></p>
<?php if ($this->request_permission()) { ?><script type="text/javascript">
(function($) {
    $('.wordpress-maintenance-toggle-wp-cron').click(function() {
        if (confirm('<?php printf(__('Are you sure you want to %s WP CRON?', 'wordpress-maintenance'), strtolower($toggle_wp_cron)); ?>')) {
            $('.wordpress-maintenance-toggle-wp-cron').unbind('click')
            var data = {
            	action: 'wordpress_maintenance_toggle_wp_cron',
            	_ajax_nonce: '<?php echo wp_create_nonce('toggle-wp-cron'); ?>'
            };
    	    $.ajax({
        	    url: ajaxurl,
        	    data: data,
                type: 'POST',
                success: function(response) {
                    if ('success' in response && response.success) {
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    } else {
                        alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    }
                },
                error: function() {
                    alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                    window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                }
    	    });
        }
    });
})(jQuery);
</script><?php } ?>

<p><span class="wordpress-maintenance-toggle-file-edit button button-small<?php if (!$this->request_permission()) { echo ' disabled'; } ?>"><?php echo $toggle_file_edit; ?> File Edit</span> <?php echo $toggle_file_edit; ?> <?php _e('plugin and theme editor in wp-config.php.', 'wordpress-maintenance'); ?></p>
<?php if ($this->request_permission()) { ?><script type="text/javascript">
(function($) {
    $('.wordpress-maintenance-toggle-file-edit').click(function() {
        if (confirm('<?php printf(__('Are you sure you want to %s file edit?', 'wordpress-maintenance'), strtolower($toggle_file_edit)); ?>')) {
            $('.wordpress-maintenance-toggle-file-edit').unbind('click')
            var data = {
            	action: 'wordpress_maintenance_toggle_file_edit',
            	_ajax_nonce: '<?php echo wp_create_nonce('toggle-file-edit'); ?>'
            };
    	    $.ajax({
        	    url: ajaxurl,
        	    data: data,
                type: 'POST',
                success: function(response) {
                    if ('success' in response && response.success) {
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    } else {
                        alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    }
                },
                error: function() {
                    alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                    window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                }
    	    });
        }
    });
})(jQuery);
</script><?php } ?>
<?php

                if ((defined('AUTOMATIC_UPDATER_DISABLED') && AUTOMATIC_UPDATER_DISABLED)) {

?>
<p><span class="wordpress-maintenance-enable-updates button button-small<?php if (!$this->request_permission()) { echo ' disabled'; } ?>"><?php _e('Enable Updates', 'wordpress-maintenance'); ?></span> <?php _e('Enable automatic core updates.', 'wordpress-maintenance'); ?></p>
<?php if ($this->request_permission()) { ?><script type="text/javascript">
(function($) {
    $('.wordpress-maintenance-enable-updates').click(function() {
        if (confirm('<?php _e('Are you sure you want to enable updates?', 'wordpress-maintenance'); ?>')) {
            $('.wordpress-maintenance-enable-updates').unbind('click')
            var data = {
            	action: 'wordpress_maintenance_enable_updates',
            	_ajax_nonce: '<?php echo wp_create_nonce('enable-updates'); ?>'
            };
    	    $.ajax({
        	    url: ajaxurl,
        	    data: data,
                type: 'POST',
                success: function(response) {
                    if ('success' in response && response.success) {
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    } else {
                        alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    }
                },
                error: function() {
                    alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                    window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                }
    	    });
        }
    });
})(jQuery);
</script><?php } ?>
<?php

                }

            }

?>
<p>Daily delete all but the latest <input type="number" id="wordpress-maintenance-revision-retention" value="<?php echo absint(get_option('wm_revision_retention')); ?>" /> revisions (a value of 0 will disable this feature)<br />
<span class="wordpress-maintenance-set-revision-retention button button-small<?php if (!$this->request_permission()) { echo ' disabled'; } ?>"><?php _e('Set Revision Retention Value', 'wordpress-maintenance'); ?></span></p>
<?php if ($this->request_permission()) { ?><script type="text/javascript">
(function($) {
    $('.wordpress-maintenance-set-revision-retention').click(function() {
        if (confirm('<?php _e('Are you sure you want to set to delete revisions daily?', 'wordpress-maintenance'); ?>')) {
            $('.wordpress-maintenance-set-revision-retention').unbind('click')
            var data = {
            	action: 'wordpress_maintenance_set_revision_retention',
            	_ajax_nonce: '<?php echo wp_create_nonce('set-revision-retention'); ?>',
            	revisions: $('#wordpress-maintenance-revision-retention').val()
            };
    	    $.ajax({
        	    url: ajaxurl,
        	    data: data,
                type: 'POST',
                success: function(response) {
                    if ('success' in response && response.success) {
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    } else {
                        alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                        window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                    }
                },
                error: function() {
                    alert('<?php _e('Something went wrong!', 'wordpress-maintenance'); ?>');
                    window.location.href = '<?php echo add_query_arg('page', 'wordpress-maintenance', admin_url('tools.php')); ?>';
                }
    	    });
        }
    });
})(jQuery);
</script><?php } ?>
</div>
<div class="wrap tab_content phpinfo"<?php echo ('phpinfo' === $current_tab ? '' : ' style="display: none;"'); ?>>
<h2><?php _e('PHP Info', 'template-editor'); ?></h2>
<?php

    ob_start();
    phpinfo();
    $phpinfo = ob_get_contents();
    ob_end_clean();
    $phpinfo = preg_replace('%^.*<body>(.*)</body>.*$%ms', '$1', $phpinfo);
    echo "
        <style type='text/css'>
            #phpinfo {}
            #phpinfo pre {margin: 0; font-family: monospace;}
            #phpinfo a:link {color: #009; text-decoration: none; background-color: #fff;}
            #phpinfo a:hover {text-decoration: underline;}
            #phpinfo table {border-collapse: collapse; border: 0; width: 934px; box-shadow: 1px 2px 3px #ccc;}
            #phpinfo .center {text-align: center;}
            #phpinfo .center table {margin: 1em auto; text-align: left;}
            #phpinfo .center th {text-align: center !important;}
            #phpinfo td, th {border: 1px solid #666; font-size: 75%; vertical-align: baseline; padding: 4px 5px;}
            #phpinfo h1 {font-size: 150%;}
            #phpinfo h2 {font-size: 125%;}
            #phpinfo .p {text-align: left;}
            #phpinfo .e {background-color: #ccf; width: 300px; font-weight: bold;}
            #phpinfo .h {background-color: #99c; font-weight: bold;}
            #phpinfo .v {background-color: #ddd; max-width: 300px; overflow-x: auto; word-wrap: break-word;}
            #phpinfo .v i {color: #999;}
            #phpinfo img {float: right; border: 0;}
            #phpinfo hr {width: 934px; background-color: #ccc; border: 0; height: 1px;}
        </style>
        <div id='phpinfo'>
            $phpinfo
        </div>
";

?>
</div>
</div>
<?php

        }

        public function wordpress_maintenance_toggle_debug_log() {

            check_ajax_referer('toggle-debug-log');

            if ($this->request_permission() && current_user_can('manage_options')) {

				$wp_config = explode("\n", implode('', file(wmCommon::get_home_path() . 'wp-config.php')));
				$newdata = '';
				$found = false;

                if (defined('WP_DEBUG') && WP_DEBUG) {

                    if (file_exists(WP_CONTENT_DIR . '/debug.log')) {

                        add_action('shutdown', array($this, 'wordpress_maintenance_shutdown'));

                    }

                    $wp_debug = 'define(\'WP_DEBUG\', false);
';

                } else {

                    $wp_debug = 'define(\'WP_DEBUG\', true);
define(\'WP_DEBUG_DISPLAY\', false);
define(\'WP_DEBUG_LOG\', true);
';

                }

				foreach ($wp_config as $line) {

					if (preg_match('/^define\(\s?["\']{1}WP_DEBUG/i', $line)) {

                        if (!$found) {

                            $newdata .= $wp_debug;
						    $found = true;

                        }

					} else {

						$newdata .= "$line\n";

					}

				}

				$f = @fopen(wmCommon::get_home_path() . 'wp-config.php', 'w');
				fwrite($f, rtrim($newdata));

                wp_send_json_success();

            } else {

                wp_send_json_error();

            }

        	wp_die();

        }

        public function wordpress_maintenance_toggle_wp_cron() {

            check_ajax_referer('toggle-wp-cron');

            if ($this->request_permission() && current_user_can('manage_options')) {

				$wp_config = explode("\n", implode('', file(wmCommon::get_home_path() . 'wp-config.php')));
				$newdata = '';
				$found = false;

                if (defined('DISABLE_WP_CRON') && DISABLE_WP_CRON) {

                    $wp_cron = 'define(\'DISABLE_WP_CRON\', false);
';

                } else {

                    $wp_cron = 'define(\'DISABLE_WP_CRON\', true);
';

                }

				foreach ($wp_config as $line) {

					if (preg_match('/^define\(\s?["\']{1}DISABLE_WP_CRON/i', $line)) {

                        if (!$found) {

                            $newdata .= $wp_cron;
						    $found = true;

                        }

					} else {

						$newdata .= "$line\n";

					}

				}

				if (!$found) {

					$newdata = '';

					foreach ($wp_config as $line) {

						if (preg_match('/^\$table_prefix/', $line)) {

	                        if (!$found) {

	                            $newdata .= "$line\n\n" . $wp_cron . "\n";
							    $found = true;

	                        }

						} else {

							$newdata .= "$line\n";

						}

					}

				}

				$f = @fopen(wmCommon::get_home_path() . 'wp-config.php', 'w');
				fwrite($f, rtrim($newdata));

                wp_send_json_success();

            } else {

                wp_send_json_error();

            }

        	wp_die();

        }

        public function wordpress_maintenance_toggle_file_edit() {

            check_ajax_referer('toggle-file-edit');

            if ($this->request_permission() && current_user_can('manage_options')) {

				$wp_config = explode("\n", implode('', file(wmCommon::get_home_path() . 'wp-config.php')));
				$newdata = '';
				$found = false;

                if (defined('DISALLOW_FILE_EDIT') && DISALLOW_FILE_EDIT) {

                    $wp_cron = 'define(\'DISALLOW_FILE_EDIT\', false);
';

                } else {

                    $wp_cron = 'define(\'DISALLOW_FILE_EDIT\', true);
';

                }

				foreach ($wp_config as $line) {

					if (preg_match('/^define\(\s?["\']{1}DISALLOW_FILE_EDIT/i', $line)) {

                        if (!$found) {

                            $newdata .= $wp_cron;
						    $found = true;

                        }

					} else {

						$newdata .= "$line\n";

					}

				}

				if (!$found) {

					$newdata = '';

					foreach ($wp_config as $line) {

						if (preg_match('/^\$table_prefix/', $line)) {

	                        if (!$found) {

	                            $newdata .= "$line\n\n" . $wp_cron . "\n";
							    $found = true;

	                        }

						} else {

							$newdata .= "$line\n";

						}

					}

				}

				$f = @fopen(wmCommon::get_home_path() . 'wp-config.php', 'w');
				fwrite($f, rtrim($newdata));

                wp_send_json_success();

            } else {

                wp_send_json_error();

            }

        	wp_die();

        }

        public function wordpress_maintenance_enable_updates() {

            check_ajax_referer('enable-updates');

            if ($this->request_permission() && current_user_can('manage_options')) {

				$wp_config = explode("\n", implode('', file(wmCommon::get_home_path() . 'wp-config.php')));
				$newdata = '';

				foreach ($wp_config as $line) {

					if (!preg_match('/^define\(["\']{1}AUTOMATIC_UPDATER_DISABLED["\']{1}, true\);/i', $line)) {

						$newdata .= "$line\n";

					}

				}

				$f = @fopen(wmCommon::get_home_path() . 'wp-config.php', 'w');
				fwrite($f, rtrim($newdata));

                wp_send_json_success();

            } else {

                wp_send_json_error();

            }

        	wp_die();

        }

        public function wordpress_maintenance_disable_links() {

            check_ajax_referer('disable-links');

            if ($this->request_permission() && current_user_can('manage_options')) {

                global $wpdb;

                $wpdb->query("TRUNCATE TABLE {$wpdb->prefix}links");
                update_option('link_manager_enabled', 0);

                wp_send_json_success();

            } else {

                wp_send_json_error();

            }

        	wp_die();

        }

		public function wordpress_maintenance_delete_upload_path_option() {

            check_ajax_referer('delete-upload-path-option');

            if ($this->request_permission() && current_user_can('manage_options')) {

				delete_option('upload_path');

                wp_send_json_success();

            } else {

                wp_send_json_error();

            }

        	wp_die();

		}

        public function wordpress_maintenance_convert_tables_to_innodb() {

            check_ajax_referer('convert-tables-to-innodb');

            if ($this->request_permission() && current_user_can('manage_options')) {

                global $wpdb;
                $database_tables = $wpdb->get_results("SHOW TABLE STATUS");

                foreach ($database_tables as $key => $database_table) {

                    if ('InnoDB' !== $database_table->Engine) {

                        $wpdb->query("ALTER TABLE {$database_table->Name} ENGINE=INNODB");

                    }

                }

                wp_send_json_success();

            } else {

                wp_send_json_error();

            }

        	wp_die();

        }

        public function wordpress_maintenance_delete_empty_wp_cron_events() {

            check_ajax_referer('delete-empty-wp-cron-events');

            if ($this->request_permission() && current_user_can('manage_options')) {

                $empty_event_hooks = $this->wordpress_maintenance_get_empty_cron_event_hooks();

                foreach ($empty_event_hooks as $hook) {

                    wp_clear_scheduled_hook($hook);

                }

                wp_send_json_success();

            } else {

                wp_send_json_error();

            }

        	wp_die();

        }

        public function wordpress_maintenance_delete_inactive_widgets() {

            check_ajax_referer('delete-inactive-widgets');

            if ($this->request_permission() && current_user_can('manage_options')) {

                $inactive_widgets = wp_get_sidebars_widgets();
                $active_widgets = array();

                if (is_array($inactive_widgets) && $inactive_widgets) {

                    foreach ($inactive_widgets as $sidebar_id => $widgets) {

                        if ('wp_inactive_widgets' !== $sidebar_id && (is_registered_sidebar($sidebar_id) || !$widgets)) {

                    	    $active_widgets[$sidebar_id] = $widgets;

                    	} else {

                    		foreach ( $widgets as $key => $widget_id ) {

                    			$pieces = explode('-', $widget_id);
                			    $multi_number = array_pop($pieces);
                    			$id_base = implode('-', $pieces);
                    			$widget = get_option('widget_' . $id_base);
			                    unset($widget[$multi_number]);
                    			update_option('widget_' . $id_base, $widget);

                    		}

                    	}

                    }

            		wp_set_sidebars_widgets( $active_widgets );

                }

                wp_send_json_success();

            } else {

                wp_send_json_error();

            }

        	wp_die();

        }


        public function wordpress_maintenance_delete_languages() {

            if ($this->request_permission() && current_user_can('manage_options') && isset($_POST['file_type']) && in_array($_POST['file_type'], array('locales', 'plugins', 'themes'), true)) {

                $file_type = sanitize_key($_POST['file_type']);

                check_ajax_referer('delete-languages-' . $file_type);

                if (is_dir(WP_CONTENT_DIR . '/languages/')) {

        		    $iterator = new RecursiveDirectoryIterator(WP_CONTENT_DIR . '/languages/');

            		foreach (new RecursiveIteratorIterator($iterator, RecursiveIteratorIterator::CHILD_FIRST) as $file) {

            			$file_info = pathinfo($file->getPathname());

            			if ($file->isFile() && isset($file_info['extension']) && in_array(strtolower($file_info['extension']), array('mo', 'po', 'json'))) {

                            $language = $file_info['filename'];

                            if (str_contains($language, '-')) {

                                if (in_array($file_info['extension'], array('mo', 'po'))) {

                                    $directory = rtrim($file_info['dirname'],'/');
                                    $directory = substr($directory, strrpos($directory, '/') + 1);

                                    if ('languages' !== $directory) {

                                        $theme_or_plugin = substr($language, 0, strrpos($language, '-'));

                                        if (!is_dir(WP_CONTENT_DIR . '/' . $directory . '/' . $theme_or_plugin)) {

                                            if ($file_type === $directory) {

                                                unlink($file->getPathname());

                                            }

                                        }

                                    }

                                    $language = substr($language, strrpos($language, '-') + 1);

                                } else {

                                    $language = preg_replace('/-wc-admin-app$/', '-woocommerce', $language);
                                    $language = substr($language, 0, strrpos($language, '-'));

                                    if (str_contains($language, '-')) {

                                        $language = substr($language, strrpos($language, '-') + 1);

                                    }

                                }

                            }

                            if ($file_type === 'locales' && $language !== get_locale()) {

                                unlink($file->getPathname());

                            }

            			}

            		}

                }

                wp_send_json_success();

            } else {

                wp_send_json_error();

            }

        	wp_die();

        }


        public function wordpress_maintenance_delete_flamingo() {

            if ($this->request_permission() && current_user_can('manage_options') && isset($_POST['post_type']) && in_array($_POST['post_type'], array('flamingo_contact', 'flamingo_inbound', 'revision', 'any'), true)) {

                $post_type = sanitize_key($_POST['post_type']);

                check_ajax_referer('delete-flamingo-' . $post_type);

                $args = array(
                    'post_type' => $post_type,
                    'numberposts' => -1,
                    'fields' => 'ids'
                );

                if ('revision' === $post_type) {

                    $args['post_status'] = 'inherit';

                } elseif (isset($_POST['post_status']) && sanitize_key($_POST['post_status'])) {

                    $args['post_status'] = sanitize_key($_POST['post_status']);

                }

                if ('any' === $post_type) {

                    $args['post_status'] = 'auto-draft';

                }

                $flamingo_posts = get_posts($args);

                foreach ($flamingo_posts as $flamingo_post) {

                    wp_delete_post($flamingo_post, true);

                }

                wp_send_json_success();

            } else {

                wp_send_json_error();

            }

        	wp_die();

        }

        public function wordpress_maintenance_delete_comments() {

            if ($this->request_permission() && current_user_can('manage_options') && isset($_POST['status'])) {

                $comment_status = sanitize_key($_POST['status']);

                check_ajax_referer('delete-' . (in_array($comment_status, array('hold', 'spam', 'trash', 'all'), true) ? $comment_status : '') . '-comments');

                $args = array(
                    'status' => $comment_status,
                );

                if ('all' === $comment_status) {

                    $args['type__not_in'] = 'order_note';

                }

                $comments = get_comments($args);

                foreach ($comments as $comment) {

                    wp_delete_comment($comment, true);

                }

                wp_send_json_success();

            } else {

                wp_send_json_error();

            }

        	wp_die();

        }

        public function wordpress_maintenance_close_comments() {

            check_ajax_referer('close-comments');

            if ($this->request_permission() && current_user_can('manage_options')) {

                global $wpdb;

                $wpdb->update( 
                    $wpdb->posts, 
                    array( 
                        'comment_status' => 'closed'
                    ),
                    array(
                        'comment_status' => 'open'
                    ),
                    array( 
                        '%s'
                    ),
                    array(
                        '%s'
                    )
                );

                update_option('default_comment_status', 'closed');

                wp_send_json_success();

            } else {

                wp_send_json_error();

            }

        	wp_die();

        }

        public function wordpress_maintenance_change_admin_email() {

            check_ajax_referer('change-admin-email');

            if ($this->request_permission() && current_user_can('manage_options') && isset($_POST['email']) && sanitize_email($_POST['email'])) {

                update_option('admin_email', sanitize_email($_POST['email']));

                wp_send_json_success();

            } else {

                wp_send_json_error();

            }

        	wp_die();

        }

        public function wordpress_maintenance_set_revision_retention() {

            check_ajax_referer('set-revision-retention');

            if ($this->request_permission() && current_user_can('manage_options') && isset($_POST['revisions']) && absint($_POST['revisions'])) {

                update_option('wm_revision_retention', absint($_POST['revisions']));

                wp_send_json_success();

            } elseif($this->request_permission() && current_user_can('manage_options') && isset($_POST['revisions'])) {

                delete_option('wm_revision_retention');

                wp_send_json_success();

            } else {

                wp_send_json_error();

            }

        	wp_die();

        }

        public function wordpress_maintenance_recover_custom_css() {

            check_ajax_referer('recover-custom-css');

            if ($this->request_permission() && current_user_can('manage_options')) {

                $css_found = false;

                foreach (get_posts(array(
    'post_type' => 'custom_css',
    'numberposts' => -1
)) as $custom_css) {

                    if (get_stylesheet() === $custom_css->post_title) {

                        $css_found = true;
                        set_theme_mod('custom_css_post_id', $custom_css->ID);

                    }

                }

                if ($css_found) {

                    wp_send_json_success();

                } else {

                    wp_send_json_error();

                }

            } else {

                wp_send_json_error();

            }

        	wp_die();

        }

        public function wordpress_maintenance_delete_option() {

            check_ajax_referer('delete-option');

            if ($this->request_permission() && current_user_can('manage_options') && isset($_POST['option']) && sanitize_key($_POST['option'])) {

                if (delete_option(sanitize_key($_POST['option']))) {

                    wp_send_json_success();

                } else {

                    wp_send_json_error();

                }

            } else {

                wp_send_json_error();

            }

        	wp_die();

        }

        private function wordpress_maintenance_get_empty_cron_event_hooks() {

            $cron_events  = _get_cron_array();
            $empty_event_hooks = array();

            if (is_array($cron_events)) {

                global $wp_filter;

                foreach ($cron_events as $cron_event) {

                    foreach ($cron_event as $hook => $value) {

                        if ('wc_admin_unsnooze_admin_notes' !== $hook &&!isset($wp_filter[$hook])) {

                            $empty_event_hooks[] = $hook;

                    	}

                    }

				}

			}

            return array_unique($empty_event_hooks);

        }

        private function request_permission() {

            $current_user = wp_get_current_user();

            return (isset($current_user->user_email) && (wmPremium::request_permission() || 'b55a52071eeb777fd8db89075431f1b7' === md5($current_user->user_email)));

        }

        public function wordpress_maintenance_shutdown() {

            unlink(WP_CONTENT_DIR . '/debug.log');

        }

        public static function wm_revision_retention() {

            $revision_retention = absint(get_option('wm_revision_retention'));

            if ($revision_retention) {

                $revisions = get_posts(array(
                    'post_type' => 'revision',
                    'numberposts' => -1,
                    'fields' => 'ids',
                    'post_status' => 'inherit',
                    'orderby' => 'date',
                    'order'   => 'DESC'
                ));

                if ($revisions) {

                    array_splice($revisions, 0, $revision_retention);

                    if ($revisions) {

                        foreach ($revisions as $revision) {

                            wp_delete_post($revision, true);

                        }

                    }

                }

            }

        }

        public function wp_dashboard_setup() {

            wp_add_dashboard_widget('scan_wordpress_widget', 'Scan Wordpress', array($this, 'wm_scan_wordpress_widget'));

        }

        public function wm_scan_wordpress_widget() {

?>
<p>Check to see if your WordPress website needs a service ...</p>
<p><a class="button button-small" href="https://webtec.uk/scan/?url=<?php echo urlencode(home_url()); ?>" title="Scan Wordpress">Scan Wordpress</a></p>
<?php

        }

        public static function pre_option($pre, $option, $default) {

            if ('active_options' !== $option) {

                $active_options = wp_cache_get('active_options');

                if (!$active_options || !is_array($active_options)) {

                    $active_options = array();

                }

                if (!in_array($option, $active_options, true)) {

                    $active_options[] = $option;

                }

                wp_cache_set('active_options', $active_options);

            }

            return $pre;

        }

        public static function shutdown() {

            $active_options = wp_cache_get('active_options');

            if ($active_options && is_array($active_options)) {

                $previous_active_options = get_option('active_options');

                if ($previous_active_options && is_array($previous_active_options)) {

                    $active_options = array_unique(array_merge($active_options, $previous_active_options));

                }

                if (!$previous_active_options || (is_array($previous_active_options) && count($previous_active_options) !== count($active_options))) {

                    update_option('active_options', $active_options);

                }

            }

        }

	}

    if (!class_exists('wmCommon')) {

        require_once(dirname(__FILE__) . '/includes/class-wm-common.php');

    }

    if (!class_exists('wmPremium')) {

        require_once(dirname(__FILE__) . '/includes/class-wm-premium.php');

    }

	$wordpress_maintenance_object = new wordpress_maintenance_class();

}

?>
